SimpleFoldingCell class

Folding Cell Widget

Inheritance

Constructors

SimpleFoldingCell.create({Key? key, required Widget? frontWidget, required Widget? innerWidget, Size? cellSize = const Size(100.0, 100.0), bool? unfoldCell = false, bool? skipAnimation = false, EdgeInsetsGeometry? padding = const EdgeInsets.only(left: 20, right: 20, bottom: 5, top: 10), Duration? animationDuration = const Duration(milliseconds: 500), double? borderRadius = 0.0, VoidCallback? onOpen, VoidCallback? onClose})

Properties

animationDuration → Duration?
Animation duration
final
borderRadius → double?
Rounded border radius
final
cellSize → Size?
Size of cell
final
frontWidget → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
innerWidget → Widget?
Inner widget in unfolded cell
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose → VoidCallback?
Called when cell unfold animations completes
final
onOpen → VoidCallback?
Called when cell fold animations completes
final
padding → EdgeInsetsGeometry?
Padding around cell
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipAnimation → bool?
If true cell will fold and unfold without animation, if false cell folding and unfolding will be animated
final
unfoldCell → bool?
If true cell will be unfolded when created, if false cell will be folded when created
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → SimpleFoldingCellState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited